@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2013  Zarafa B.V.
+ * Copyright 2005 - 2014  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -130,10 +130,17 @@
 			$result = NOERROR;
 
 			if(is_string($username) && is_string($password)) {
+				if(function_exists("openssl_decrypt")) {
+					$password = openssl_decrypt($password,"des-ede3-cbc",PASSWORD_KEY,0,PASSWORD_IV);
+				}
 				// logon
 				$this->session = mapi_logon_zarafa($username, $password, $server, $sslcert_file, $sslcert_pass);
 				$result = mapi_last_hresult();
 
+				if(function_exists("openssl_encrypt")) {
+					$password = openssl_encrypt($password,"des-ede3-cbc",PASSWORD_KEY,0,PASSWORD_IV);
+				}
+
 				if ($result == NOERROR && $this->session !== false){
 					$this->session_info["username"] = $username;
 					$this->session_info["password"] = $password;
